@@ -8,7 +8,9 @@
 #include "sieveeditormainwindow.h"
 #include <KAboutData>
 #include <KCrash>
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
 #include <KDBusService>
+#endif
 #include <KLocalizedString>
 #include <QApplication>
 #include <QCommandLineParser>
@@ -18,12 +20,31 @@
 #include <KUserFeedback/Provider>
 #endif
 
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
+
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
+
 int main(int argc, char **argv)
 {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
     QApplication app(argc, argv);
     app.setDesktopFileName(QStringLiteral("org.kde.sieveeditor"));
     KCrash::initialize();
-
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+#endif // HAVE_STYLE_MANAGER
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("sieveeditor"));
 
     KAboutData aboutData(QStringLiteral("sieveeditor"),
@@ -32,7 +53,7 @@ int main(int argc, char **argv)
                          i18n("Sieve Editor"),
                          KAboutLicense::GPL_V2,
                          i18n("Copyright © 2013-%1 sieveeditor authors", QStringLiteral("2024")));
-    aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("sieveeditor")));
     KAboutData::setApplicationData(aboutData);
@@ -40,7 +61,7 @@ int main(int argc, char **argv)
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 #ifdef WITH_KUSERFEEDBACK
-    const QCommandLineOption feedbackOption(QStringLiteral("feedback"), i18n("Lists the available options for user feedback"));
+    const QCommandLineOption feedbackOption(QStringLiteral("feedback"), i18nc("@info:shell", "Lists the available options for user feedback"));
     parser.addOption(feedbackOption);
 #endif
     parser.process(app);
@@ -53,7 +74,9 @@ int main(int argc, char **argv)
     }
 #endif
 
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
     KDBusService service(KDBusService::Unique);
+#endif
 
     auto mw = new SieveEditorMainWindow();
     mw->show();
